@@ -2,15 +2,6 @@
 # These are never used in the inner loop
 
 
-def normcdf(x):
-    g = backward_compat_normcdf_function()
-    return g(x)
-
-
-def normpdf(x):
-    g = backward_compat_normpdf_function()
-    return g(x)
-
 
 def backward_compat_normcdf_function():
     try:
@@ -23,6 +14,22 @@ def backward_compat_normcdf_function():
         except ImportError:
             raise Exception('You need to install scipy or a version of Python with statistics.NormalDist')
 
+normcdf = backward_compat_normcdf_function()
+
+
+def backward_compat_invnormcdf_function():
+    try:
+        from statistics import NormalDist
+        return NormalDist(mu=0, sigma=1.0).inv_cdf
+    except ImportError:
+        try:
+            from scipy.stats import norm
+            return norm.ppf
+        except ImportError:
+            raise Exception('You need to install scipy or a version of Python with statistics.NormalDist')
+
+invnormcdf = backward_compat_invnormcdf_function()
+
 
 def backward_compat_normpdf_function():
     try:
@@ -34,3 +41,7 @@ def backward_compat_normpdf_function():
             return norm.pdf
         except ImportError:
             raise Exception('You need to install scipy or a version of Python with statistics.NormalDist')
+
+
+normpdf = backward_compat_normpdf_function()
+
